@@ -34,7 +34,7 @@
 ;; Models defined at https://docs.anthropic.com/claude/docs/models-overview
 (cl-defstruct (llm-claude (:include llm-standard-chat-provider))
   (key nil :read-only t)
-  (chat-model "claude-sonnet-4-0" :read-only t))
+  (chat-model "claude-sonnet-4-5" :read-only t))
 
 (cl-defmethod llm-nonfree-message-info ((_ llm-claude))
   "Return Claude's nonfree ToS."
@@ -59,8 +59,8 @@
                    :max_tokens ,(or (llm-chat-prompt-max-tokens prompt)
                                     (cond ((string-match "opus-4-0" (llm-claude-chat-model provider))
                                            32000)
-                                          ((or (string-match "sonnet-4-0" (llm-claude-chat-model provider))
-                                               (string-match "sonnet-3-7" (llm-claude-chat-model provider)))
+                                          ((or (string-match "4" (llm-claude-chat-model provider))
+                                               (string-match "3-7" (llm-claude-chat-model provider)))
                                            64000)
                                           ((string-match "opus" (llm-claude-chat-model provider))
                                            4096)
@@ -95,10 +95,32 @@
                                (vconcat
                                 (mapcar (lambda (f) (llm-claude--tool-call f))
                                         (llm-chat-prompt-tools prompt))))))
+    (when (and (llm-chat-prompt-response-format prompt)
+               (member 'json-response (llm-capabilities provider))
+               (not (eq 'json (llm-chat-prompt-response-format prompt))))
+      (setq request (plist-put request :output_format
+                               `(:type "json_schema"
+                                       :schema ,(let ((schema (llm-chat-prompt-response-format prompt)))
+                                                  (unless (plist-get schema :additionalProperties)
+                                                    (setq schema (plist-put schema :additionalProperties :false)))
+                                                  (llm-provider-utils-convert-to-serializable
+                                                   schema))))))
     (when (> (length system) 0)
       (setq request (plist-put request :system system)))
     (when (llm-chat-prompt-temperature prompt)
       (setq request (plist-put request :temperature (llm-chat-prompt-temperature prompt))))
+    (when-let* ((options (llm-chat-prompt-tool-options prompt)))
+      (setq request (plist-put request :tool_choice
+                               (append
+                                (list :type (pcase (llm-tool-options-tool-choice options)
+                                              ('auto "auto")
+                                              ('any "any")
+                                              ('none "none")
+                                              ((pred stringp) "tool")
+                                              (_ (error "Unknown tool choice option: %s"
+                                                        (llm-tool-options-tool-choice options)))))
+                                (when (stringp (llm-tool-options-tool-choice options))
+                                  (list :name (llm-tool-options-tool-choice options)))))))
     (when (llm-chat-prompt-reasoning prompt)
       (setq request (plist-put request :thinking
                                (let (thinking-plist)
@@ -246,11 +268,13 @@ DATA is a vector of lists produced by `llm-provider-streaming-media-handler'."
     (nreverse result)))
 
 (cl-defmethod llm-provider-headers ((provider llm-claude))
-  `(("x-api-key" . ,(if (functionp (llm-claude-key provider))
-                        (funcall (llm-claude-key provider))
-                      (llm-claude-key provider)))
-    ("anthropic-version" . "2023-06-01")
-    ("anthropic-beta" . "tools-2024-04-04")))
+  (append
+   `(("x-api-key" . ,(if (functionp (llm-claude-key provider))
+                         (funcall (llm-claude-key provider))
+                       (llm-claude-key provider)))
+     ("anthropic-version" . "2023-06-01"))
+   (when (member 'json-response (llm-capabilities provider))
+     '(("anthropic-beta" . "structured-outputs-2025-11-13")))))
 
 (cl-defmethod llm-provider-chat-extract-error ((_ llm-claude) response)
   (when-let ((err (assoc-default 'error response)))
@@ -272,8 +296,11 @@ DATA is a vector of lists produced by `llm-provider-streaming-media-handler'."
   "Return the name of the provider."
   "Claude")
 
-(cl-defmethod llm-capabilities ((_ llm-claude))
-  (list 'streaming 'tool-use 'streaming-tool-use 'image-input 'pdf-input 'reasoning))
+(cl-defmethod llm-capabilities ((provider llm-claude))
+  (seq-union
+   '(streaming tool-use streaming-tool-use image-input pdf-input reasoning)
+   (when-let* ((model (llm-models-match (llm-claude-chat-model provider))))
+     (llm-model-capabilities model))))
 
 (cl-defmethod llm-provider-append-to-prompt ((_ llm-claude) prompt result
                                              &optional tool-use-results)
